==> javautils-sparkserver-0.0.1-sources.jar: tecgraf/javautils/sparkserver/standard/JuRoute.java <==
package tecgraf.javautils.sparkserver.standard;

import java.util.UUID;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import tecgraf.javautils.sparkserver.core.JuIFunction;
import tecgraf.javautils.sparkserver.exceptions.JuAuthorizationException;
import tecgraf.javautils.sparkserver.exceptions.JuException;
import tecgraf.javautils.sparkserver.exceptions.JuPermissionException;
import tecgraf.javautils.sparkserver.utils.JuSparkUtilities;

import spark.Request;
import spark.Response;
import spark.Route;

public class JuRoute<T> implements Route {

  private final Logger logger = LoggerFactory.getLogger(this.getClass());
  private final JuIFunction<T> function;

  public JuRoute(JuIFunction<T> function) {
    if (function == null) {
      throw new IllegalArgumentException("null function not allowed!");
    }
    this.function = function;
  }

  @Override
  public Object handle(Request request, Response response) throws Exception {
    final String hashString = UUID.randomUUID().toString();
    try {
      logger.info(getLoggerId(">>", null, hashString, request.pathInfo()));
      final T object = function.call(request, response);
      logger.info(getLoggerId("<<", 200, hashString, String.format("status %d", response.status())));
      return object;
    }
    catch (JuException e) {
      final String err = e.getMessage();
      final int statusCode = e.getStatusCode();
      logger.warn(getLoggerId("XX", statusCode, hashString, err));
      return JuSparkUtilities.setResponseAsText(response, statusCode, err);
    }
    catch (Throwable t) {
      final String err = t.getMessage();
      final int statusCode = 500;
      logger.error(getLoggerId("!!", statusCode, hashString, err), t);
      return JuSparkUtilities.setResponseAsText(response, statusCode, err);
    }
  }

  private String getLoggerId(String prefix, Integer statusCode, String hashString, String text) {
    if (statusCode == null) {
      return String.format("%s [%s]: %s", prefix, hashString, text);
    }
    return String.format("%s [%s] (%02d): %s", prefix, hashString, statusCode, text);
  }

}

==> javautils-sparkserver-0.0.2-sources.jar: tecgraf/javautils/sparkserver/standard/JuRoute.java <==
package tecgraf.javautils.sparkserver.standard;

import java.util.UUID;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import tecgraf.javautils.sparkserver.core.JuIFunction;
import tecgraf.javautils.sparkserver.exceptions.JuException;
import tecgraf.javautils.sparkserver.utils.JuResponseUtilities;

import spark.Request;
import spark.Response;
import spark.Route;

public class JuRoute<T> implements Route {

  private final Logger logger = LoggerFactory.getLogger(this.getClass());
  private final JuIFunction<T> function;

  public JuRoute(JuIFunction<T> function) {
    if (function == null) {
      throw new IllegalArgumentException("null function not allowed!");
    }
    this.function = function;
  }

  @Override
  public Object handle(Request request, Response response) throws Exception {
    final String hashString = UUID.randomUUID().toString();
    try {
      logger.info(getLoggerId(">>", null, hashString, request.pathInfo()));
      final T object = function.call(request, response);
      logger.info(getLoggerId("<<", 200, hashString, String.format("status %d", response.status())));
      return object;
    }
    catch (JuException e) {
      final String err = e.getMessage();
      final int statusCode = e.getStatusCode();
      logger.warn(getLoggerId("XX", statusCode, hashString, err));
      return JuResponseUtilities.setResponseAsText(response, statusCode, err);
    }
    catch (Throwable t) {
      final String err = t.getMessage();
      final int statusCode = 500;
      logger.error(getLoggerId("!!", statusCode, hashString, err), t);
      return JuResponseUtilities.setResponseAsText(response, statusCode, err);
    }
  }

  private String getLoggerId(String prefix, Integer statusCode, String hashString, String text) {
    if (statusCode == null) {
      return String.format("%s [%s]: %s", prefix, hashString, text);
    }
    return String.format("%s [%s] (%02d): %s", prefix, hashString, statusCode, text);
  }

}
